## Checklist

- [ ] Discussed idea or confident it's critical (See Contribute.md).
- [ ] One feature/bug per PR (unless minor/related).
- [ ] PR is from a **feature branch**, not `main`.
- [ ] I ran at least one example to ensure the code works.
- [ ] Checked linting/formatting (`uv run ruff format && uv run ruff check`).

---

## Description

<!-- Short description of the feature/bug this PR resolve; Optional: Closes #123 -->
